==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dock-network-plugin/translations/dock-network-plugin_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Tinklas</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Prieigos taškas</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokolas</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Saugumo tipas</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Juosta</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanalas</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Sąsaja</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Tinklo kaukė</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tinklų sietuvas</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Pirminis DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Priešdelis</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Greitis</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Įrenginys išjungtas</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Prisijungta, bet nėra prieigos prie interneto</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neprijungta</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Atjungtas tinklo laidas</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Jungiamasi</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Nustatoma tapatybė</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Gaunamas IP adresas</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Prisijungta</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Atsijungta</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Nepavyko</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Laidinis tinklas</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Laidinis tinklas %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Belaidis tinklas</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Belaidis tinklas %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Įrenginys išjungtas</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Atjungtas tinklo laidas</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neprijungta</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Jungiamasi</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Prisijungta, bet nėra prieigos prie interneto</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Išjungti laidinį ryšį</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Įjungti laidinį ryšį</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Išjungti belaidį ryšį</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Įjungti belaidį ryšį</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Išjungti tinklą</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Įjungti tinklą</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Tinklo nustatymai</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.7.orig.tar.xz: dde-network-core-1.1.7/dock-network-plugin/translations/dock-network-plugin_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Belaidis tinklas</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Laidinis tinklas</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Tinklas</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Prisijungti prie paslėpto tinklo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Prisijungti</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Prieigos taškas</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokolas</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Saugumo tipas</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanalas</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Juosta</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Sąsaja</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Tinklo kaukė</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tinklų sietuvas</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Pirminis DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Priešdelis</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Greitis</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Įrenginys išjungtas</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Prisijungta, bet nėra prieigos prie interneto</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neprijungta</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Atjungtas tinklo laidas</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Jungiamasi</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Nustatoma tapatybė</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Gaunamas IP adresas</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Prisijungta</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Atsijungta</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Nepavyko</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Laidinis tinklas</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Laidinis tinklas %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Belaidis tinklas</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Belaidis tinklas %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Įrenginys išjungtas</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Atjungtas tinklo laidas</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neprijungta</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Jungiamasi</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Prisijungta, bet nėra prieigos prie interneto</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Išjungti laidinį ryšį</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Įjungti laidinį ryšį</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Išjungti belaidį ryšį</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Įjungti belaidį ryšį</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Išjungti tinklą</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Įjungti tinklą</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Tinklo nustatymai</translation>
    </message>
</context>
</TS>
